package com.tocea.easycoverage.framework.checkers;

import java.lang.reflect.Method;

import com.tocea.easycoverage.framework.ClassChecker;
import com.tocea.easycoverage.framework.api.IInstanceProvider;
import com.tocea.easycoverage.framework.exception.EasycoverageAssertionError;

/**
 * 
 * Checkers that verifies that equals does not return null, for each class
 * implementing it.
 * 
 * @author Romain Delamare
 * 
 */
public class NullValueEqualsChecker extends ClassChecker {

	public NullValueEqualsChecker(final IInstanceProvider provider,
			final Class<?> clazz) {
		super(provider, clazz);
	}

	public void check() {
		if (provider != null) {
			final Object o = provider.getInstance(clazz);
			if (o.equals(null))
				throw new EasycoverageAssertionError(
						"object.equals(null) should always be false.");
		}
	}

	@Override
	public boolean shouldCheck() {
		Method equals = null;
		if (clazz != null)
			try {
				equals = clazz.getDeclaredMethod("equals");
			} catch (final SecurityException e) {
				// nothing to do
			} catch (final NoSuchMethodException e) {
				// nothing to do
			}
		return super.shouldCheck() && equals != null;
	}

}
